import { NgComponentOutlet, NgForOf, NgIf } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, Injector, Component, ChangeDetectionStrategy, Inject, NgModule, Injectable } from '@angular/core';
import * as i1 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i2 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { ContentContainerComponentHarness, HarnessPredicate } from '@angular/cdk/testing';
import { MatButtonHarness } from '@angular/material/button/testing';
import { MatDialogHarness } from '@angular/material/dialog/testing';
import { firstValueFrom } from 'rxjs';

/**
 * Injection token for a custom dialog component to receive input. See {@link DialogData.slDialogData}.
 */
const SL_DIALOG_DATA = new InjectionToken('SL_DIALOG_DATA');
/**
 * The {@link DialogButton.value} for the default "OK" button that is used if you do not specify any custom buttons for your dialog.
 */
const DEFAULT_OK_VALUE = Symbol('OK');
class DialogComponent {
    constructor(data, injector) {
        this.data = data;
        data.buttons ??= [{ text: 'OK', value: DEFAULT_OK_VALUE }];
        this.componentInjector = Injector.create({
            providers: [{ provide: SL_DIALOG_DATA, useValue: data.slDialogData }],
            parent: injector,
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: DialogComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.0", type: DialogComponent, isStandalone: true, selector: "sl-dialog", ngImport: i0, template: "<h2 mat-dialog-title>{{ data.title ?? data.component?.title }}</h2>\n\n<mat-dialog-content class=\"mat-typography\">\n  <p *ngIf=\"data.text\">{{ data.text }}</p>\n  <ng-container *ngIf=\"data.component\">\n    <ng-container\n      *ngComponentOutlet=\"data.component; injector: componentInjector\"\n    ></ng-container>\n  </ng-container>\n</mat-dialog-content>\n\n<mat-dialog-actions align=\"end\">\n  <button\n    *ngFor=\"let button of data.buttons\"\n    mat-button\n    [mat-dialog-close]=\"button.value ?? button.text\"\n    [color]=\"button.color ?? 'primary'\"\n  >\n    {{ button.text }}\n  </button>\n</mat-dialog-actions>\n", styles: ["mat-dialog-actions button{text-transform:uppercase}\n"], dependencies: [{ kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i1.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i2.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i2.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i2.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: i2.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: NgComponentOutlet, selector: "[ngComponentOutlet]", inputs: ["ngComponentOutlet", "ngComponentOutletInjector", "ngComponentOutletContent", "ngComponentOutletNgModule", "ngComponentOutletNgModuleFactory"] }, { kind: "directive", type: NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: DialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sl-dialog', standalone: true, imports: [MatButtonModule, MatDialogModule, NgComponentOutlet, NgForOf, NgIf], changeDetection: ChangeDetectionStrategy.OnPush, template: "<h2 mat-dialog-title>{{ data.title ?? data.component?.title }}</h2>\n\n<mat-dialog-content class=\"mat-typography\">\n  <p *ngIf=\"data.text\">{{ data.text }}</p>\n  <ng-container *ngIf=\"data.component\">\n    <ng-container\n      *ngComponentOutlet=\"data.component; injector: componentInjector\"\n    ></ng-container>\n  </ng-container>\n</mat-dialog-content>\n\n<mat-dialog-actions align=\"end\">\n  <button\n    *ngFor=\"let button of data.buttons\"\n    mat-button\n    [mat-dialog-close]=\"button.value ?? button.text\"\n    [color]=\"button.color ?? 'primary'\"\n  >\n    {{ button.text }}\n  </button>\n</mat-dialog-actions>\n", styles: ["mat-dialog-actions button{text-transform:uppercase}\n"] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i0.Injector }]; } });

/**
 * Harness for interacting with a dialog opened via {@link SlDialogService.open}.
 */
class SlDialogHarness extends ContentContainerComponentHarness {
    static { this.hostSelector = 'sl-dialog'; }
    #getContent = this.locatorFor('mat-dialog-content');
    /**
     * Gets a `HarnessPredicate` that can be used to search for a SlDialogHarness that meets certain criteria.
     */
    static with(options) {
        return new HarnessPredicate(SlDialogHarness, options).addOption('title', options.title, async (harness, title) => HarnessPredicate.stringMatches(harness.getTitle(), title));
    }
    async getTitle() {
        const title = await this.locatorFor('[mat-dialog-title]')();
        return title.text();
    }
    /**
     * Get the text displayed in the content of the dialog. Note this includes text from both the `text` and `component` options of {@link SlDialogService.open}.
     */
    async getContentText() {
        const content = await this.#getContent();
        return content.text();
    }
    /**
     * Return the text of all the buttons.
     */
    async getButtonText() {
        const buttons = await this.#getButtons();
        return Promise.all(buttons.map(async (button) => button.getText()));
    }
    /**
     * Return the text of all the buttons. Note that "default" corresponds to when you explicitly specify that color for the button, and is **not** the color of a button when you don't specify a color (see {@link DialogButton.color}).
     */
    async getButtonColors() {
        const buttons = await this.#getButtons();
        return Promise.all(buttons.map(async (button) => {
            const host = await button.host();
            if (await host.hasClass('mat-primary')) {
                return 'primary';
            }
            else if (await host.hasClass('mat-accent')) {
                return 'accent';
            }
            else if (await host.hasClass('mat-warn')) {
                return 'warn';
            }
            else {
                return 'default';
            }
        }));
    }
    async clickButton(text) {
        const button = await this.#getButton(text);
        await button.click();
    }
    /**
     * Closes the dialog by pressing escape.
     */
    async close() {
        const rootLoader = await this.documentRootLocatorFactory().rootHarnessLoader();
        const dialog = await rootLoader.getHarness(MatDialogHarness);
        await dialog.close();
    }
    async #getButton(text) {
        const footer = await this.#getFooter();
        return footer.getHarness(MatButtonHarness.with({ text }));
    }
    async #getButtons() {
        const footer = await this.#getFooter();
        return footer.getAllHarnesses(MatButtonHarness);
    }
    async #getFooter() {
        return this.getChildLoader('mat-dialog-actions');
    }
}

/**
 * Import this module to enable use of {@linkcode SlDialogService}
 */
class SlDialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: SlDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.0.0", ngImport: i0, type: SlDialogModule, imports: [MatDialogModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: SlDialogModule, imports: [MatDialogModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: SlDialogModule, decorators: [{
            type: NgModule,
            args: [{ imports: [MatDialogModule] }]
        }] });

/**
 * Shows simple text dialogs with just a method call, and reduces boilerplate for more complex dialogs.
 *
 * A simple text dialog:
 * ```ts
 * const choice = await slDialogService.open({
 *   text: 'Discard draft?',
 *   buttons: [{ text: 'Cancel' }, { text: 'Discard' }]
 * });
 * if (choice === 'Discard') {
 *   // discard the draft
 * }
 * ```
 *
 * Using a custom component:
 * ```ts
 * @Component({
 *   template: `
 *     <h3>Heading 1</h3>
 *     <p>Paragraph 1</p>
 *     <h3>Heading 2</h3>
 *     <p>Paragraph 2</p>
 *   `
 * })
 * class FancyDialogComponent {}
 *
 * slDialogService.open({
 *   title: 'My title',
 *   component: FancyDialogComponent,
 * });
 * ```
 */
class SlDialogService {
    constructor(matDialog) {
        this.matDialog = matDialog;
    }
    /**
     * Resolves when the dialog is closed. Resolves to the {@link DialogButton.value} of the clicked button, or to `undefined` if the dialog was closed another way (such as clicking off it).
     */
    async open(data) {
        const ref = this.matDialog.open(DialogComponent, {
            data,
            autoFocus: false,
        });
        return firstValueFrom(ref.beforeClosed());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: SlDialogService, deps: [{ token: i2.MatDialog }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: SlDialogService, providedIn: SlDialogModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: SlDialogService, decorators: [{
            type: Injectable,
            args: [{ providedIn: SlDialogModule }]
        }], ctorParameters: function () { return [{ type: i2.MatDialog }]; } });

/*
 * Public API Surface of ng-mat-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DEFAULT_OK_VALUE, SL_DIALOG_DATA, SlDialogHarness, SlDialogModule, SlDialogService };
//# sourceMappingURL=ng-mat-core.mjs.map
